/*----------------------------------------------------------*/
/*	Copyright (C) Siemens AG (2003). All Rights Reserved	*/
/*	Product:		SIMATIC PDM								*/
/*															*/
/*	Device:			P&F Remote I/O for PROFIBUS DP			*/
/*	Function:		Detect-Methode							*/
/*	Description:	Device Description						*/
/*	Version:		V1.00.00								*/
/*	Dictionary:		---										*/
/*															*/
/*	Date:			17.03.03	iLu							*/
/*	Modified:		xx.xx.xx	                        	*/
/*----------------------------------------------------------*/


MANUFACTURER    93,
DEVICE_TYPE     1,
DEVICE_REVISION 0x0200,
DD_REVISION     38


#define PATH_DEVICE_NOT_FOUND		""
#define PATH_PuF_FB_V4				"\\IO_Systeme\\PuF\\PuF_LBFB_V4\\Buskoppler\\BK_FB"
#define PATH_PuF_LB_V4				"\\IO_Systeme\\PuF\\PuF_LBFB_V4\\Buskoppler\\BK_LB"
#define PATH_PuF_FB_V6				"\\IO_Systeme\\PuF\\PuF_LBFB_V6\\Buskoppler\\BK_FB"
#define PATH_PuF_LB_V6				"\\IO_Systeme\\PuF\\PuF_LBFB_V6\\Buskoppler\\BK_LB"

#define	BK_TYPE_FB_V4				0x8203
#define	BK_TYPE_LB_V4				0x8103

#define	BK_TYPE_FB_V6				0x8205
#define	BK_TYPE_LB_V6				0x8105

#define	BK_TYPE_FB_V9				0x8209
#define	BK_TYPE_LB_V9				0x8109



/*******************************************************************************/
/*****	Methods	****************************************************************/
/*******************************************************************************/

METHOD std_DetectDevice
{
	LABEL "std_DetectDevice";
	DEFINITION
	{
		ret_DetectDevice = PATH_DEVICE_NOT_FOUND;

		_TRACE ("std_DetectDevice: P&F Remote IO - LB/FB");

		ReadCommand(read_P0_BK_Type);

		if (P0_BK_Type == BK_TYPE_FB_V4)
		{
			ret_DetectDevice = PATH_PuF_FB_V4;
		}
		else if (P0_BK_Type == BK_TYPE_LB_V4)
		{
			ret_DetectDevice = PATH_PuF_LB_V4;
		}
		else if (P0_BK_Type == BK_TYPE_FB_V6)
		{
			ret_DetectDevice = PATH_PuF_FB_V6;
		}
		else if (P0_BK_Type == BK_TYPE_LB_V6)
		{
			ret_DetectDevice = PATH_PuF_LB_V6;
		}
		else if (P0_BK_Type == BK_TYPE_FB_V9)
		{
			ret_DetectDevice = PATH_PuF_FB_V6;
		}
		else if (P0_BK_Type == BK_TYPE_LB_V9)
		{
			ret_DetectDevice = PATH_PuF_LB_V6;
		}

		_TRACE ("  --> ret_DetectDevice =" + ret_DetectDevice);
	}
}

/*******************************************************************************/
/*****	Variables	************************************************************/
/*******************************************************************************/

VARIABLE ret_DetectDevice
{
	LABEL		"ret_DetectDevice";
	CLASS		TEMPORARY;
	TYPE		ASCII(255)
	{
		DEFAULT_VALUE PATH_DEVICE_NOT_FOUND;
	}
	HANDLING	READ;
}


VARIABLE    Loc_P0_BK_Slot0
{
    LABEL     [P0_Slot0];
    HELP      [P0_Slot0_help];
    TYPE      ENUMERATED(1)
    {
		DEFAULT_VALUE 0;
    }
	CLASS		LOCAL;
    HANDLING	READ & WRITE;
}


VARIABLE	P0_BK_Type
{
	LABEL		[P0_Type];
	HELP		[P0_Type_help];
	TYPE		ENUMERATED (2)
	{
		{ 0x8103,	[buskoppler_LB_V4] },		// V4
		{ 0x8203,	[buskoppler_FB_V4] },		// V4
		{ 0x8105,   [buskoppler_LB_V6] },		// V6
		{ 0x8205,   [buskoppler_FB_V6] },		// V6
		{ 0x8109,   [buskoppler_LB_V9] },		// V9
		{ 0x8209,   [buskoppler_FB_V9] }		// V9
	}
	CLASS		CONTAINED;
	HANDLING	READ & WRITE;
}

/*******************************************************************************/
/*****	Commands	************************************************************/
/*******************************************************************************/

COMMAND read_P0_BK_Type
{
	SLOT		Loc_P0_BK_Slot0;
	INDEX		0;
	OPERATION	READ;
	TRANSACTION
	{
		REQUEST
		{			
		}
		REPLY
		{
			0,													// P0_BK_Slot0,
			0,													// P0_BK_Index0,
			0, 0, 0, 0, 0, 0, 0, 0,   0, 0, 0, 0, 0, 0, 0, 0,	// P0_BK_Tag,
			0, 0, 0, 0, 0, 0, 0, 0,   0, 0, 0, 0, 0, 0, 0, 0,	// P0_BK_Tag,
			P0_BK_Type,
			0,													// P0_BK_Channel,
			0,													// P0_BK_Sector,
			0, 0,												// P0_BK_Option_...
			0, 0, 0, 0,											// P0_BK_Time,
			0, 0, 0, 0,											// P0_BK_Revision,
			0, 0, 0, 0, 0, 0, 0, 0,   0, 0, 0, 0, 0, 0,			// P0_BK_DUMMY,
			0, 0												// P0_BK_Reserviert
		}
	}
}
